"use strict";(self["webpackChunkSimple_Web_based_Interface_for_Scanner"]=self["webpackChunkSimple_Web_based_Interface_for_Scanner"]||[]).push([[750],{6750:(e,n,t)=>{t.r(n),t.d(n,{default:()=>p});var a=t(3673);const c=(0,a.Uk)("Start scanning");function r(e,n,t,r,s,f){const o=(0,a.up)("q-btn"),u=(0,a.up)("q-page");return(0,a.wg)(),(0,a.j4)(u,{class:"flex flex-center"},{default:(0,a.w5)((()=>[(0,a.Wm)(o,{icon:"scanner",to:"/scan",style:{"font-size":"3rem"}},{default:(0,a.w5)((()=>[c])),_:1})])),_:1})}const s=(0,a.aZ)({name:"PageIndex",data:function(){return{}},methods:{}});var f=t(4260),o=t(4379),u=t(4607),_=t(7518),l=t.n(_);const d=(0,f.Z)(s,[["render",r]]),p=d;l()(s,"components",{QPage:o.Z,QBtn:u.Z})}}]);