"use strict";(self["webpackChunkSimple_Web_based_Interface_for_Scanner"]=self["webpackChunkSimple_Web_based_Interface_for_Scanner"]||[]).push([[614],{5614:(e,t,n)=>{n.r(t),n.d(t,{default:()=>d});var l=n(3673);const s={class:"fullscreen bg-blue text-white text-center q-pa-md flex flex-center"},c=(0,l._)("div",{style:{"font-size":"30vh"}},"404",-1),r=(0,l._)("div",{class:"text-h2",style:{opacity:"0.4"}},"Oops. Nothing here...",-1);function o(e,t,n,o,a,i){const u=(0,l.up)("q-btn");return(0,l.wg)(),(0,l.iD)("div",s,[(0,l._)("div",null,[c,r,(0,l.Wm)(u,{class:"q-mt-xl",color:"white","text-color":"blue",unelevated:"",to:"/",label:"Go Home","no-caps":""})])])}const a=(0,l.aZ)({name:"Error404"});var i=n(4260),u=n(4607),_=n(7518),f=n.n(_);const b=(0,i.Z)(a,[["render",o]]),d=b;f()(a,"components",{QBtn:u.Z})}}]);