"use strict";(self["webpackChunkSimple_Web_based_Interface_for_Scanner"]=self["webpackChunkSimple_Web_based_Interface_for_Scanner"]||[]).push([[110],{5110:(e,n,t)=>{t.r(n),t.d(n,{default:()=>D});var a=t(3673);const l=(0,a.Uk)("Simple Web-based Interface for Scanner"),o=(0,a.Uk)("Menu");function i(e,n,t,i,r,u){const c=(0,a.up)("q-btn"),s=(0,a.up)("q-toolbar-title"),d=(0,a.up)("q-toolbar"),p=(0,a.up)("q-header"),m=(0,a.up)("q-item-label"),f=(0,a.up)("EssentialLink"),w=(0,a.up)("q-list"),k=(0,a.up)("q-drawer"),_=(0,a.up)("router-view"),b=(0,a.up)("q-page-container"),g=(0,a.up)("q-layout");return(0,a.wg)(),(0,a.j4)(g,{view:"lHh Lpr lFf"},{default:(0,a.w5)((()=>[(0,a.Wm)(p,{elevated:""},{default:(0,a.w5)((()=>[(0,a.Wm)(d,null,{default:(0,a.w5)((()=>[(0,a.Wm)(c,{flat:"",dense:"",round:"",icon:"menu","aria-label":"Menu",onClick:e.toggleLeftDrawer},null,8,["onClick"]),(0,a.Wm)(s,null,{default:(0,a.w5)((()=>[l])),_:1})])),_:1})])),_:1}),(0,a.Wm)(k,{modelValue:e.leftDrawerOpen,"onUpdate:modelValue":n[0]||(n[0]=n=>e.leftDrawerOpen=n),"show-if-above":"",bordered:""},{default:(0,a.w5)((()=>[(0,a.Wm)(w,null,{default:(0,a.w5)((()=>[(0,a.Wm)(m,{header:""},{default:(0,a.w5)((()=>[o])),_:1}),((0,a.wg)(!0),(0,a.iD)(a.HY,null,(0,a.Ko)(e.essentialLinks,(e=>((0,a.wg)(),(0,a.j4)(f,(0,a.dG)({key:e.title},e),null,16)))),128))])),_:1})])),_:1},8,["modelValue"]),(0,a.Wm)(b,null,{default:(0,a.w5)((()=>[(0,a.Wm)(_)])),_:1})])),_:1})}var r=t(2323);function u(e,n,t,l,o,i){const u=(0,a.up)("q-icon"),c=(0,a.up)("q-item-section"),s=(0,a.up)("q-item-label"),d=(0,a.up)("q-item");return(0,a.wg)(),(0,a.j4)(d,{clickable:"",tag:"a",onClick:e.gotourl},{default:(0,a.w5)((()=>[e.icon?((0,a.wg)(),(0,a.j4)(c,{key:0,avatar:""},{default:(0,a.w5)((()=>[(0,a.Wm)(u,{name:e.icon},null,8,["name"])])),_:1})):(0,a.kq)("",!0),(0,a.Wm)(c,null,{default:(0,a.w5)((()=>[(0,a.Wm)(s,null,{default:(0,a.w5)((()=>[(0,a.Uk)((0,r.zw)(e.title),1)])),_:1}),(0,a.Wm)(s,{caption:""},{default:(0,a.w5)((()=>[(0,a.Uk)((0,r.zw)(e.caption),1)])),_:1})])),_:1})])),_:1},8,["onClick"])}const c=(0,a.aZ)({name:"EssentialLink",props:{title:{type:String,required:!0},caption:{type:String,default:""},link:{type:String,default:"#"},icon:{type:String,default:""}},methods:{gotourl(){window.location.href.endsWith(this.link)?window.location.reload():window.location.href=this.link}}});var s=t(4260),d=t(3414),p=t(2035),m=t(4554),f=t(2350),w=t(7518),k=t.n(w);const _=(0,s.Z)(c,[["render",u]]),b=_;k()(c,"components",{QItem:d.Z,QItemSection:p.Z,QIcon:m.Z,QItemLabel:f.Z});var g=t(1959);const W=[{title:"Scan",caption:"Scan image",icon:"scanner",link:"/#/scan"},{title:"Images",caption:"List of images",icon:"photo_library",link:"/#/scans"}],Z=(0,a.aZ)({name:"MainLayout",components:{EssentialLink:b},setup(){const e=(0,g.iH)(!1);return{essentialLinks:W,leftDrawerOpen:e,toggleLeftDrawer(){e.value=!e.value}}}});var q=t(3066),h=t(3812),L=t(9570),Q=t(4607),S=t(3747),v=t(2428),y=t(7011),I=t(2652);const C=(0,s.Z)(Z,[["render",i]]),D=C;k()(Z,"components",{QLayout:q.Z,QHeader:h.Z,QToolbar:L.Z,QBtn:Q.Z,QToolbarTitle:S.Z,QDrawer:v.Z,QList:y.Z,QItemLabel:f.Z,QPageContainer:I.Z})}}]);